#define MOZ_SOURCE_STAMP 327e081221b064b05a302d7877c6e4be2949a617
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-release
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-release/rev/327e081221b064b05a302d7877c6e4be2949a617
